@@ -25,26 +25,22 @@ no_toc = true
 title_page = true
 title = "Config Title"
 author = "Config Author"
-pandoc_args = "--number-sections"
+pandoc_args ="--number-sections"
 """
     )
 
     # 3) chdir into tmp_path so script sees ./​.mdfusion
     monkeypatch.chdir(tmp_path)
 
-    # 4) Stub out subprocess.run to capture the cmd
+    # 4) Stub out mdfusion.run_pandoc_with_spinner to capture the cmd
     captured = {}
 
-    def fake_run(cmd, check, capture_output, text):
+    def fake_spinner(cmd, out_pdf):
         captured["cmd"] = cmd
-
-        class Result:
-            pass
-
-        return Result()
+        print(f"Merged PDF written to {out_pdf}")
 
     # call with no args => pick up config
-    monkeypatch.setattr(subprocess, "run", fake_run)
+    monkeypatch.setattr(mdfusion, "run_pandoc_with_spinner", fake_spinner)
     mdfusion.main()
 
     # 6) Check printed output
@@ -59,6 +55,8 @@ pandoc_args = "--number-sections"
     # no_toc=true means --toc must NOT appear
     assert "--toc" not in cmd
 
+    print(cmd, file=sys.stderr)
+
     # title_page=true doesn't affect flags here, but pandoc_args does:
     assert "--number-sections" in cmd
 
